@@ -1,4 +1,5 @@
 import math
+import functools
 from functools import partial
 from typing import Optional, Union
 
@@ -43,7 +44,7 @@ def hinge_gen_loss(fake):
     return -fake.mean()
 
 def leaky_relu(p = 0.1):
-    return nn.LeakyReLU(0.1)
+    return nn.LeakyReLU(p)
 
 def gradient_penalty(images, output, weight = 10):
     batch_size = images.shape[0]
@@ -298,6 +299,7 @@ class SoundStream(nn.Module):
     ):
         super().__init__()
         self.single_channel = input_channels == 1
+        self.strides = strides
 
         layer_channels = tuple(map(lambda t: t * channels, channel_mults))
         layer_channels = (channels, *layer_channels)
@@ -348,6 +350,10 @@ class SoundStream(nn.Module):
         self.adversarial_loss_weight = adversarial_loss_weight
         self.feature_loss_weight = feature_loss_weight
 
+    @property
+    def seq_len_multiple_of(self):
+        return functools.reduce(lambda x, y: x * y, self.strides)
+
     def forward(
         self,
         x,
